Package 'nycdogs'

Title: New York City dog licenses and bite incidents by zip code
Description: A data package containing three data sets covering dog ownership in New York City.
Authors: Kieran Healy [aut, cre]
Maintainer: Kieran Healy <[email protected]>
License: MIT + file LICENSE
Version: 0.2
Built: 2026-05-12 09:34:49 UTC
Source: https://github.com/kjhealy/nycdogs

Help Index


New York City Dog Reported Dog bites

Description

Reported dog bite incidents in New York city between January 1st 2015 and Decenber 31st 2017,

Usage

nyc_bites

Format

A tibble containing 10,280 rows and 11 columns

uniqueid

Incident identified.

date_of_bite

Date of bite.

species

Species of animal (all "Dog").

breed

Breed of dog.

age

Age of dog.

gender

Sex of dog.

spay_neuter

Spayed or neutered (True/False)

borough

Borough where bite occurred.

zip_code

Zip code where bite occurred.

year

Year

breed_rc

Recoded breed variable with aggregated breed categories)

New York City public data


Dogs of New York

Description

Active Dog Licenses in New York City as of February 2025.

Usage

nyc_license

Format

## 'nyc_license' A data frame with 722,864 rows and 12 columns:

animal_name

Name of dog

animal_gender

Sex of dog

animal_birth_year

Year dog was born

breed_name

Dog breed

breed_rc

Lightly recoded breed

zip_code

Owner zip code. Same as zip, retained for compatibility with nyc_bites.

zip

Owner zip code

license_issued_date

Date license issued.

license_expired_date

Date license expires.

extract_year

Year this record was queried.

borough

Borough of Owner. (Some zip codes are in more than one borough but here are counted only once.)

city

Nominal city, based on zip code.

Details

he data is sourced from the DOHMH Dog Licensing System (https://a816-healthpsi.nyc.gov/DogLicense), where owners can apply for and renew dog licenses. Each record represents a unique dog license that was active during the year, but not necessarily a unique record per dog, since a license that is renewed during the year results in a separate record of an active license period. Each record stands as a unique license period for the dog over the course of the yearlong time frame.

Author(s)

Kieran Healy

Sourced from NYC Open Data <https://data.cityofnewyork.us/Health/NYC-Dog-Licensing-Dataset/nu7n-tubp>