| Title: | New York City dog licenses and bite incidents by zip code |
|---|---|
| Description: | A data package containing three data sets covering dog ownership in New York City. |
| Authors: | Kieran Healy [aut, cre] |
| Maintainer: | Kieran Healy <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2 |
| Built: | 2026-05-12 09:34:49 UTC |
| Source: | https://github.com/kjhealy/nycdogs |
Reported dog bite incidents in New York city between January 1st 2015 and Decenber 31st 2017,
nyc_bitesnyc_bites
A tibble containing 10,280 rows and 11 columns
uniqueidIncident identified.
date_of_biteDate of bite.
speciesSpecies of animal (all "Dog").
breedBreed of dog.
ageAge of dog.
genderSex of dog.
spay_neuterSpayed or neutered (True/False)
boroughBorough where bite occurred.
zip_codeZip code where bite occurred.
yearYear
breed_rcRecoded breed variable with aggregated breed categories)
New York City public data
Active Dog Licenses in New York City as of February 2025.
nyc_licensenyc_license
## 'nyc_license' A data frame with 722,864 rows and 12 columns:
Name of dog
Sex of dog
Year dog was born
Dog breed
Lightly recoded breed
Owner zip code. Same as zip, retained for compatibility with nyc_bites.
Owner zip code
Date license issued.
Date license expires.
Year this record was queried.
Borough of Owner. (Some zip codes are in more than one borough but here are counted only once.)
Nominal city, based on zip code.
he data is sourced from the DOHMH Dog Licensing System (https://a816-healthpsi.nyc.gov/DogLicense), where owners can apply for and renew dog licenses. Each record represents a unique dog license that was active during the year, but not necessarily a unique record per dog, since a license that is renewed during the year results in a separate record of an active license period. Each record stands as a unique license period for the dog over the course of the yearlong time frame.
Kieran Healy
Sourced from NYC Open Data <https://data.cityofnewyork.us/Health/NYC-Dog-Licensing-Dataset/nu7n-tubp>